<?php

/**
 * @file
 * Contains \Drupal\otp_verification\Form\MiniorangeGeneralSettings.
 */

namespace Drupal\otp_verification\Form;

use Drupal\Core\Form\FormBase;
use Drupal\otp_verification\MiniorangeOtpCustomer;
use Drupal\otp_verification\MiniorangeOtpUtilities;
use Drupal\otp_verification\MiniorangeOtpVerificationConstants;


class MiniorangeConfiguration extends FormBase
{
    /**
    * {@inheritdoc}
    */
    public function getFormId() {
        return 'miniorange_mapping';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        global $base_url, $_miniorange_otp_msg;
        $config = \Drupal::config('otp_verification.settings');

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "otp_verification/otp_verification.admin",
                )
            ),
        );

        if (!MiniorangeOtpUtilities::isCustomerRegistered()) {
            $register_url = $base_url . '/admin/config/people/otp_verification/customer_setup';
            $form['header'] = array(
                '#markup' => '<div class="mo_saml_configure_message">You need to <a href="'.$register_url.'" >register/login</a> with miniOrange before using this module.</div>',
            );

        }

        $baseUrl = 'https://login.xecurify.com';

        self::miniorange_otp_handle_mo_check_ln($_miniorange_otp_msg);
        $smstemp = 'https://login.xecurify.com/moas/login?redirectUrl=https://login.xecurify.com/moas/admin/customer/showsmstemplate';
        $smsconfig = 'https://login.xecurify.com/moas/login?redirectUrl=https://login.xecurify.com/moas/admin/customer/smsconfig';
        $emailtemp = 'https://login.xecurify.com/moas/login?redirectUrl=https://login.xecurify.com/moas/admin/customer/emailtemplateconfiguration';
        $emailconfig = 'https://login.xecurify.com/moas/login?redirectUrl=https://login.xecurify.com/moas/admin/customer/configureSMTP';

        $var = $config->get('mo_customer_check_ln');
        $admin_email =  $config->get('miniorange_otp_verification_customer_admin_email');

        $otp_length_config = 'https://login.xecurify.com/moas/login?username='.$admin_email.'&redirectUrl=' .$baseUrl . '/moas/admin/customer/customerpreferences';

        $pcode = MiniorangeOtpCustomer::$pcode;
        $bcode = MiniorangeOtpCustomer::$bcode;

        $form['markup_1'] = array(
            '#markup' => '<div class="mo_otp_verification_table_layout_1"><div class="mo_otp_verification_table_layout mo_otp_container">
                        <h2>SMS & EMAIL CONFIGURATION</h2><hr><hr><br/>',
        );

        $form['markup_headLine'] = array(
            '#markup' => '<div class="mo_otp_verification_highlight_background_note"><b>Look at the sections below to customize the Email and SMS that you receive:</b></div><br>'
        );

        if(MiniorangeOtpUtilities::isCustomerRegistered())
        {
            $custom_sms = 'https://login.xecurify.com/moas/login?username='.$admin_email.'&redirectUrl=https://login.xecurify.com/moas/admin/customer/showsmstemplate';
            $custom_sms_gateway = 'https://login.xecurify.com/moas/login?username='.$admin_email.'&redirectUrl=https://login.xecurify.com/moas/admin/customer/smsconfig';
            $custom_email = 'https://login.xecurify.com/moas/login?username='.$admin_email.'&redirectUrl=https://login.xecurify.com/moas/admin/customer/emailtemplateconfiguration';
            $custom_email_gateway = 'https://login.xecurify.com/moas/login?username='.$admin_email.'&redirectUrl=https://login.xecurify.com/moas/admin/customer/configureSMTP';
            $targetBlank = 'target="_blank"';
        } else {
            $custom_sms = $base_url.'/admin/config/people/otp_verification/customer_setup';
            $custom_sms_gateway = $base_url.'/admin/config/people/otp_verification/customer_setup';
            $custom_email = $base_url.'/admin/config/people/otp_verification/customer_setup';
            $custom_email_gateway = $base_url.'/admin/config/people/otp_verification/customer_setup';
            $targetBlank = '';
        }

        $form['markup_2'] = array(
            '#markup' => '1. <a href="'.$custom_sms.'" '.$targetBlank.'>Custom SMS Template</a> : Change the text of the message that you receive on your phones.<br>'
            . '2. <a href="'.$custom_sms_gateway.'" '.$targetBlank.'>Custom SMS Gateway</a> : You can configure settings to use your own SMS gateway.<br>'
            . '3. <a href="'.$custom_email.'" '.$targetBlank.'>Custom Email Template</a> : Change the text of the email that you receive.<br>'
            . '4. <a href="'.$custom_email_gateway.'" '.$targetBlank.'>Custom Email Gateway</a> : You can configure settings to use your own Email gateway.<br><br>',
        );

        $form['markup_3'] = array(
            '#markup' => '<div class="mo_otp_verification_highlight_background_note"><b> How can I change the SenderID/Number of the SMS I receive?</b></div>'
            . '<div id="q1" class="" ><ol><li>SenderID/Number is gateway specific. You will need to use your own SMS gateway for this.</li></ol></div><br>',
        );

        $form['markup_4'] = array(
            '#markup' => '<div class="mo_otp_verification_highlight_background_note"><b>How can I change the Sender Email of the Email I receive?</b><br></div>'
            . '<div id="q2" class="" ><ol><li>Sender Email is gateway specific. You will need to use your own Email gateway for this.</li></ol></div><br>',
        );

        $url = $base_url . '/admin/config/people/otp_verification/Licensing';
        $desable_feature = "";
        $premium_feature = "";
        if($var != $pcode && $var != $bcode) {
            $desable_feature = 'disabled = "true"';
            $premium_feature = '[Premium Feature]';
        }

        $form['otp_length'] = array(
            '#markup' => '<br><h2>OTP PREFERENCES</h2><hr><hr><br/>',
        );

        $form['markup_headLine1'] = array(
            '#markup' => '<div class="mo_saml_highlight_background_note"><b>Look at the sections below to customize the OTP that you receive:</b></div><br>'
        );

        $form['otp_length_custom1'] = array(
            '#markup' => '1. <a href="'.$otp_length_config.'" target="_blank">Custom OTP length</a> : You can configure settings to use custom OTP length.<br>',
        );

        $form['otp_length_custom2'] = array(
            '#markup' => '2. <a href="'.$otp_length_config.'" target="_blank">Custom OTP Validity</a> (in mins) : You can configure settings to use custom OTP Validity (in mins).<br><br>',
        );

        MiniorangeOtpUtilities::AddSupportButton( $form, $form_state);

        $form['main_layout_div_end_1'] = array(
                '#markup' => '</div><div>',
            );

        MiniorangeOtpUtilities::Two_FA_Advertisement($form, $form_state);

        return $form;
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

    }

    /**
    * Check license.
    */
    public function miniorange_otp_handle_mo_check_ln($showmessage) {

        $db_var = \Drupal::configFactory()->getEditable('otp_verification.settings');

        $challenge_otp = new MiniorangeOtpCustomer(NULL, NULL, NULL, NULL);
        $content = json_decode($challenge_otp->checkCustomerLn(), TRUE);
        $license_plan = isset($content['licensePlan'])? $content['licensePlan'] : '';
        $current_status = '';

        if (strcasecmp($content['status'], 'SUCCESS') == 0) {

            array_key_exists('licensePlan', $content) && !MiniorangeOtpCustomer::moCheckEmptyOrNull($content['licensePlan']) ? $db_var->set('mo_customer_check_ln',base64_encode($content['licensePlan']))->save() : $db_var->set('mo_customer_check_ln','')->save();

            if ($showmessage) {

                array_key_exists('licensePlan', $content) && !MiniorangeOtpCustomer::moCheckEmptyOrNull($content['licensePlan']) ? \Drupal::messenger()->addMessage(t('Thank you, you have been upgraded to @license_name', array('@license_name' => $license_plan)), 'status') : \Drupal::messenger()->addMessage(t('You are on our FREE plan, check Licensing Tab to learn how to upgrade.'), 'status');

                if (array_key_exists('licensePlan', $content) && !MiniorangeOtpCustomer::moCheckEmptyOrNull($content['licensePlan'])) {
                    $db_var->set('mo_customer_email_transactions_remaining', $current_status)
                           ->set('mo_customer_phone_transactions_remaining', $current_status)
                           ->set('mo_otp_plugin_version', $current_status)
                           ->set('mo_customer_validation_transaction_message', $current_status)
                           ->save();
                }
            }
        } elseif (strcasecmp($content['status'], 'FAILED') == 0) {
            array_key_exists('licensePlan', $content) && !MiniorangeOtpCustomer::moCheckEmptyOrNull($content['licensePlan']) ? \Drupal::messenger()->addMessage(t('Thank you, you have been upgraded to @license_name', array('@license_name' => $license_plan)), 'status')  : \Drupal::messenger()->addMessage(t('You are on our FREE plan, check Licensing Tab to learn how to upgrade.'), 'status');
        }
    }
}
